@@ -1,8 +1,8 @@
 var searchData=
 [
-  ['unofficial_0',['Others (Unofficial)',['..//buildsys/main/opencc/src/OpenCC-ver.1.1.9/README.md#autotoc_md15',1,'']]],
-  ['usage_20使用_1',['Usage 使用',['..//buildsys/main/opencc/src/OpenCC-ver.1.1.9/README.md#autotoc_md6',1,'']]],
-  ['using_20opencc_20使用_20opencc_20的項目_2',['Projects using OpenCC 使用 OpenCC 的項目',['..//buildsys/main/opencc/src/OpenCC-ver.1.1.9/README.md#autotoc_md27',1,'']]],
+  ['unofficial_0',['Others (Unofficial)',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md15',1,'']]],
+  ['usage_20使用_1',['Usage 使用',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md6',1,'']]],
+  ['using_20opencc_20使用_20opencc_20的項目_2',['Projects using OpenCC 使用 OpenCC 的項目',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md28',1,'']]],
   ['utf8stringslicebase_3',['UTF8StringSliceBase',['../classopencc_1_1_u_t_f8_string_slice_base.html',1,'opencc']]],
   ['utf8stringslicebase_3c_20size_5ft_20_3e_4',['UTF8StringSliceBase&lt; size_t &gt;',['../classopencc_1_1_u_t_f8_string_slice_base.html',1,'opencc']]],
   ['utf8stringslicebase_3c_20unsigned_20char_20_3e_5',['UTF8StringSliceBase&lt; unsigned char &gt;',['../classopencc_1_1_u_t_f8_string_slice_base.html',1,'opencc']]],
