@@ -1,7 +1,7 @@
 var searchData=
 [
   ['dartsdict_0',['DartsDict',['../classopencc_1_1_darts_dict.html',1,'opencc']]],
-  ['demo_20線上轉換展示_1',['Online demo 線上轉換展示',['..//buildsys/main/opencc/src/OpenCC-ver.1.1.9/README.md#autotoc_md7',1,'']]],
+  ['demo_20線上轉換展示_1',['Online demo 線上轉換展示',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md7',1,'']]],
   ['dict_2',['Dict',['../classopencc_1_1_dict.html',1,'opencc']]],
   ['dictentry_3',['DictEntry',['../classopencc_1_1_dict_entry.html',1,'opencc']]],
   ['dictentryfactory_4',['DictEntryFactory',['../classopencc_1_1_dict_entry_factory.html',1,'opencc']]],
