@@ -1,7 +1,7 @@
 var searchData=
 [
-  ['installation_20安裝_0',['Installation 安裝',['..//buildsys/main/opencc/src/OpenCC-ver.1.1.9/README.md#autotoc_md3',1,'']]],
-  ['introduction_20介紹_1',['Introduction 介紹',['..//buildsys/main/opencc/src/OpenCC-ver.1.1.9/README.md#autotoc_md1',1,'']]],
+  ['installation_20安裝_0',['Installation 安裝',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md3',1,'']]],
+  ['introduction_20介紹_1',['Introduction 介紹',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md1',1,'']]],
   ['invalidformat_2',['InvalidFormat',['../classopencc_1_1_invalid_format.html',1,'opencc']]],
   ['invalidtextdictionary_3',['InvalidTextDictionary',['../classopencc_1_1_invalid_text_dictionary.html',1,'opencc']]],
   ['invalidutf8_4',['InvalidUTF8',['../classopencc_1_1_invalid_u_t_f8.html',1,'opencc']]],
