@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['javascript_0',['JavaScript',['..//buildsys/main/opencc/src/OpenCC-ver.1.1.9/README.md#autotoc_md9',1,'']]],
+  ['javascript_0',['JavaScript',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md9',1,'']]],
   ['join_1',['Join',['../classopencc_1_1_u_t_f8_util.html#af97a85b5420283fab1e06b68a3d27fe5',1,'opencc::UTF8Util::Join(const std::vector&lt; std::string &gt; &amp;strings, const std::string &amp;separator)'],['../classopencc_1_1_u_t_f8_util.html#ab6041a2629499b1f61d99e4c2476d4dc',1,'opencc::UTF8Util::Join(const std::vector&lt; std::string &gt; &amp;strings)']]],
-  ['js_2',['Node.js',['..//buildsys/main/opencc/src/OpenCC-ver.1.1.9/README.md#autotoc_md8',1,'']]]
+  ['js_2',['Node.js',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md8',1,'']]]
 ];
